[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

ooqstart-gnome



Hi,

given that you seem MIA and didn't fix easy to fix bugs for a long time
and the current ooqstart-gnome needs updates for OOo2 - because OOo2
changed interface and the openoffice.org 2.0.x-y packages conflict against
the current ooqstart-gnome in sid; not to mention that because of this
fact ooqstart-gnome will block OOo2 transition to testing - I decided to
hijack the package.[1]

IMHO it is best to maintain it inside the Debian OOo Team anyway because
the package is so closely related to OOo.

If you want, I can give if back to you though or I (or you yourself) can
add you to Uploaders:

The package was uploaded to DELAYED/7-day, where also the changes and the
diff can be found; the interdiff is attached for completeness' sake.

Regards,

Rene

[1] which was discussed on #debian-devel; and the people there agreed
diff -u ooqstart-0.8.3/console/console.cxx ooqstart-0.8.3/console/console.cxx
--- ooqstart-0.8.3/console/console.cxx
+++ ooqstart-0.8.3/console/console.cxx
@@ -1,5 +1,5 @@
 /*=========================================================================
-| Open Office QuickStarter
+| OpenOffice.org QuickStarter
 |--------------------------------------------------------------------------
 | (c) 2002  Kumaran Santhanam  <kumaran@alumni.stanford.org>
 |
@@ -33,7 +33,7 @@
     Model model;
 	model.setOpenOfficeProgram (argv[1]);
     if (!model.isValid()) {
-        printf("error: Open Office executable not found in %s\n", argv[1]);
+        printf("error: OpenOffice.org executable not found in %s\n", argv[1]);
         return 1;
     }
     
diff -u ooqstart-0.8.3/help/index.html ooqstart-0.8.3/help/index.html
--- ooqstart-0.8.3/help/index.html
+++ ooqstart-0.8.3/help/index.html
@@ -1,15 +1,15 @@
 <html>
 <head>
-<title>Open Office QuickStarter applet</title>
+<title>OpenOffice.org QuickStarter applet</title>
 </head>
 
 <body bgcolor="#ffffff">
-<h1>Open Office QuickStarter applet</h1>
+<h1>OpenOffice.org QuickStarter applet</h1>
 
-<p> This applet provides a quick launcher for Open Office 641C+
+<p> This applet provides a quick launcher for OpenOffice.org 641C+
 or Star Office 6.0+.  It attempts to mimic the functionality
 provided by the quickstarter tray icon on the other operating
-system supported by Open Office.
+system supported by OpenOffice.org.
 
 <p> The program attempts to keep a background process alive at
 all times, even if that process is terminated by the user.
diff -u ooqstart-0.8.3/model.cxx ooqstart-0.8.3/model.cxx
--- ooqstart-0.8.3/model.cxx
+++ ooqstart-0.8.3/model.cxx
@@ -24,9 +24,8 @@
 static const char *SDRAW    = "private:factory/sdraw";
 static const char *SIMPRESS = "private:factory/simpress";
 
-static const char *PLUGIN   = "-plugin";
-static const char *QSTART   = "-quickstart";
-
+static const char *NOLOGO   = "-nologo";
+static const char *NODEFAULT = "-nodefault"; 
 
 /*=========================================================================
 | INCLUDES
@@ -72,7 +71,7 @@
 	}
 
     // Child process execution point
-    execl(path, path, arg1, arg2, arg3, 0);
+    execlp(arg1,arg1, arg2, arg3, NULL);
     
     // Execution should never reach this point.
     // If it does, there was an error.
@@ -98,7 +97,7 @@
 | CONSTRUCTOR / DESTRUCTOR
  ========================================================================*/
 Model::Model () {
-    _enabled    = false;
+    _enabled    = true;
     _daemonPID  = 0;
     _tick       = 0;
     _status     = MODEL_OFFICE_STOPPED;
@@ -161,7 +160,7 @@
     // accidentally terminated.
     if (_enabled) {
         if (!running && _soffice != 0) {
-            _daemonPID = startProcess(BIN_SH, _soffice, PLUGIN, QSTART);
+            _daemonPID = startProcess(BIN_SH, _soffice, NOLOGO, NODEFAULT);
             _status    = MODEL_OFFICE_STARTING;
             _tick      = time(0);
         }
diff -u ooqstart-0.8.3/model.h ooqstart-0.8.3/model.h
--- ooqstart-0.8.3/model.h
+++ ooqstart-0.8.3/model.h
@@ -1,5 +1,5 @@
 /*=========================================================================
-| Open Office QuickStarter
+| OpenOffice.org QuickStarter
 |--------------------------------------------------------------------------
 | (c) 2002  Kumaran Santhanam  <kumaran@alumni.stanford.org>
 |     2003  Filip Van Raemdonck <mechanix@debian.org>
diff -u ooqstart-0.8.3/debian/changelog ooqstart-0.8.3/debian/changelog
--- ooqstart-0.8.3/debian/changelog
+++ ooqstart-0.8.3/debian/changelog
@@ -1,3 +1,20 @@
+ooqstart (0.8.3-9) unstable; urgency=low
+
+  * Hijack; the current version blocks ooqstart usage with OOo2 and will
+    block OOo2 transition to testing...
+  * restrict Architecture: to i386, powerpc, sparc since OOo is only
+    available there (closes: #216685)
+  * fix "missing sentinel in function call" (closes: #337408)
+  * update for OOo2's incompatible option changes (closes: #340450) and
+    therefore increase the Recommends to openoffice.org (>= 2.0.0) and
+    conflict against openoffice.org (<< 2.0.0).
+  * Add patch from SuSE to make the preloading default and remove the option.
+    (closes: #282833, #320358).
+  * fix FSFs address in debian/copyright
+  * s/Open Office/OpenOffice.org/ in various places (closes: #320386)
+
+ -- Rene Engelhard <rene@debian.org>  Sun, 11 Dec 2005 21:21:18 +0100
+
 ooqstart (0.8.3-8) unstable; urgency=medium
 
   * Don't ship empty /usr/bin. (Closes: #192754)
diff -u ooqstart-0.8.3/debian/control ooqstart-0.8.3/debian/control
--- ooqstart-0.8.3/debian/control
+++ ooqstart-0.8.3/debian/control
@@ -1,14 +1,16 @@
 Source: ooqstart
 Section: gnome
 Priority: optional
-Maintainer: Filip Van Raemdonck <mechanix@debian.org>
+Maintainer: Debian OpenOffice Team <debian-openoffice@lists.debian.org>
+Uploaders: Rene Engelhard <rene@debian.org>, Chris Halls <halls@debian.org>
 Build-Depends: debhelper (>> 4), libpanel-applet2-dev, sharutils
 Standards-Version: 3.5.6.1
 
 Package: ooqstart-gnome
-Architecture: any
+Architecture: i386 powerpc sparc
 Depends: ${shlibs:Depends}
-Recommends: openoffice.org
+Recommends: openoffice.org (>= 2.0.0)
+Conflicts: openoffice.org (<< 2.0.0)
 Description: OpenOffice.org QuickStarter applet for GNOME 2
  This applet preloads the OpenOffice.org program to make it launch faster
  when needed.
diff -u ooqstart-0.8.3/debian/copyright ooqstart-0.8.3/debian/copyright
--- ooqstart-0.8.3/debian/copyright
+++ ooqstart-0.8.3/debian/copyright
@@ -7,7 +7,6 @@
-
 Copyright: Released under the GPL.
 
 You should have received a copy of the GNU General Public License with the
 Debian GNU/Linux distribution in file /usr/share/common-licenses/GPL; if
-not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite
-330, Boston, MA 02111-1307 USA	
+not, write to the  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+Boston, MA 02110-1301, USA.
only in patch2:
unchanged:
--- ooqstart-0.8.3.orig/ChangeLog
+++ ooqstart-0.8.3/ChangeLog
@@ -1,4 +1,4 @@
-Open Office QuickStarter applet
+OpenOffice.org QuickStarter applet
 
 v0.8.3  Kumaran Santhanam  <kumaran@alumni.stanford.org>
   - auto-size pixmaps for variable panel sizes
only in patch2:
unchanged:
--- ooqstart-0.8.3.orig/README
+++ ooqstart-0.8.3/README
@@ -1,9 +1,9 @@
-Open Office QuickStarter applet
+OpenOffice.org QuickStarter applet
 
-This applet provides a quick launcher for Open Office 641C+ or Star
+This applet provides a quick launcher for OpenOffice.org 641C+ or Star
 Office 6.0+.  It attempts to mimic the functionality provided by the
 quickstarter tray icon on the other operating system supported by
-Open Office.
+OpenOffice.org.
 
 The program attempts to keep a background process alive at all
 times, even if that process is terminated by the user. The four main
only in patch2:
unchanged:
--- ooqstart-0.8.3.orig/package/ooqstart-gnome.spec
+++ ooqstart-0.8.3/package/ooqstart-gnome.spec
@@ -1,4 +1,4 @@
-# RPM spec file for Open Office QuickStarter applet
+# RPM spec file for OpenOffice.org QuickStarter applet
 #
 # (C) 2002  Kumaran Santhanam  <kumaran@alumni.stanford.org>
 # This project is released under the GNU General Public License v2.
@@ -6,7 +6,7 @@
 %define version    0.8.3
 %define release    1
 
-Summary: Open Office QuickStarter applet
+Summary: OpenOffice.org QuickStarter applet
 Name: ooqstart-gnome
 Version: %{version}
 Release: %{release}
@@ -20,10 +20,10 @@
 Provides: ooqstart
 
 %description
-This applet provides a quick launcher for Open Office 641C+
+This applet provides a quick launcher for OpenOffice.org 641C+
 or Star Office 6.0+.  It attempts to mimic the functionality
 provided by the quickstarter tray icon on the other operating
-system supported by Open Office.
+system supported by OpenOffice.org.
 
 The program attempts to keep a background process alive at
 all times, even if that process is terminated by the user.
only in patch2:
unchanged:
--- ooqstart-0.8.3.orig/package/debian/control
+++ ooqstart-0.8.3/package/debian/control
@@ -8,8 +8,8 @@
 Package: ooqstart-gnome
 Architecture: any
 Depends: ${shlibs:Depends}
-Description: Open Office QuickStarter applet for GNOME
- This applet provides a quick launcher for Open Office 641C+ or
+Description: OpenOffice.org QuickStarter applet for GNOME
+ This applet provides a quick launcher for OpenOffice.org 641C+ or
  Star Office 6.0+. It attempts to mimic the functionality provided 
  by the quickstarter tray icon on the other operating system supported 
- by Open Office.
+ by OpenOffice.org.
only in patch2:
unchanged:
--- ooqstart-0.8.3.orig/www/index.html
+++ ooqstart-0.8.3/www/index.html
@@ -1,19 +1,19 @@
 <html>
 <head>
-<title>Open Office QuickStarter applet</title>
+<title>OpenOffice.org QuickStarter applet</title>
 </head>
 
 <body bgcolor="#ffffff">
 <font face="helvetica,arial,sans-serif">
 
-<h1>Open Office QuickStarter applet</h1>
+<h1>OpenOffice.org QuickStarter applet</h1>
 
 <h2>Introduction</h2>
 
-<p> This applet provides a quick launcher for Open Office 641C+
+<p> This applet provides a quick launcher for OpenOffice.org 641C+
 or Star Office 6.0+.  It attempts to mimic the functionality
 provided by the quickstarter tray icon on the other operating
-system supported by Open Office.
+system supported by OpenOffice.org.
 
 <p> The program attempts to keep a background process alive at
 all times, even if that process is terminated by the user.

Attachment: signature.asc
Description: Digital signature


Reply to:
diff -u ooqstart-0.8.3/gnome/gnome.cxx ooqstart-0.8.3/gnome/gnome.cxx
--- ooqstart-0.8.3/gnome/gnome.cxx
+++ ooqstart-0.8.3/gnome/gnome.cxx
@@ -1,5 +1,5 @@
 /*=========================================================================
-| Open Office QuickStarter
+| OpenOffice.org QuickStarter
 |--------------------------------------------------------------------------
 | (c) 2002  Kumaran Santhanam  <kumaran@alumni.stanford.org>
 |
@@ -32,7 +32,7 @@
 #define PACKAGE "ooqstart"
 #define GETTEXT_PACKAGE "ooqstart"
 
-#define OOFFICE_DEFAULT_PATH "/usr/bin/openoffice"
+#define OOFFICE_DEFAULT_PATH "/usr/bin/ooffice"
 
 #define GC_PROG_PATH "/ooqstart-applet/paths/program"
 #define GC_APPLET_ENABLE "/ooqstart-applet/prefs/enable"
@@ -45,7 +45,6 @@
 static GtkWidget *propwindow;
 static GtkWidget *applet;
 static GtkWidget *entry;
-static GtkWidget *checkbox;
 
 static GtkWidget *tile;
 static GtkWidget *tilepixmap;
@@ -176,7 +175,7 @@
 | SESSION MANAGEMENT
  ========================================================================*/
 // These functions are necessary to disable GNOME session management
 // for the Open Office binary.  Specifically, the binary should not
 // be relaunched upon login.
 // 
 // Session management is rather nasty.  Please see the GNOME documentation
@@ -257,7 +256,7 @@
                 if (strcmp(program, val) == 0) {
                     // If we got this far, we have found the
                     // correct client.
-                    printf("Open Office session %s = %s\n", handle, val);
+                    printf("OpenOffice.org session %s = %s\n", handle, val);
                     if (sessionHandle)  free(sessionHandle);
                     sessionHandle = strdup(handle);
                     disableRestart(sessionHandle);
@@ -317,16 +316,11 @@
 static void
 loadConfig (Model* pModel) {
 	pModel->setOpenOfficeProgram (gnome_config_get_string (GC_PROG_PATH "=" OOFFICE_DEFAULT_PATH));
-	if (gnome_config_get_bool (GC_APPLET_ENABLE "=false"))
-		pModel->enable();
-    else
-		pModel->disable();
 }
 
 static void
 saveConfig (Model* pModel) {
 	gnome_config_set_string (GC_PROG_PATH, pModel->getOpenOfficeProgram());
-	gnome_config_set_bool (GC_APPLET_ENABLE, pModel->getEnabled());
 
     gnome_config_sync();
 }
@@ -341,9 +335,6 @@
 
 	Model* pModel = (Model*) data;
 
-    // Get the status of the checkbox
-    bool enable = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbox));
-
     // Check to see if the given path is valid
 	pModel->setOpenOfficeProgram (gtk_entry_get_text (GTK_ENTRY (entry)));
 	if (!pModel->isValid()) {
@@ -354,16 +345,8 @@
 		        "The QuickStarter applet will be disabled.\n"));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
-
-        // Disable the quick starter
-        enable = false;
     }
 
-    if (enable)
-		pModel->enable();
-    else
-		pModel->disable();
-
 	saveConfig (pModel);
 /* FIXME: applet_widget_sync_config(PANEL_APPLET(applet)); */
     propwindow = 0;
@@ -414,16 +397,6 @@
     gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
     gtk_widget_show(label);
     
-    checkbox = gtk_check_button_new_with_label
-        (_("Enable QuickStarter"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), pModel->getEnabled());
-    gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
-    gtk_signal_connect_object
-        (GTK_OBJECT(checkbox), "clicked",
-         GTK_SIGNAL_FUNC(gnome_property_box_changed),
-         GTK_OBJECT(propwindow));
-    gtk_widget_show(checkbox);
-
     label = gtk_label_new(_("General"));
     gnome_property_box_append_page
         (GNOME_PROPERTY_BOX(propwindow), vbox, label);
@@ -448,9 +421,9 @@
         authors[2] = 0;
 
         about = gnome_about_new
-            ( _("Open Office QuickStarter Applet"), VERSION,
+            ( _("OpenOffice.org QuickStarter Applet"), VERSION,
               _("(C) 2002 Kumaran Santhanam\n    2003 Filip Van Raemdonck"),
-              _("Quick starter launch applet for Open Office 641C+ "
+              _("Quick starter launch applet for OpenOffice.org 641C+ "
                 "and Star Office 6.0+.\n"
                 "Right-click on the applet icon for a context menu.\n"
                 " \n"
@@ -176,7 +175,7 @@
  ========================================================================*/
 // These functions are necessary to disable GNOME session management
-// for the Open Office binary.  Specifically, the binary should not
+// for the OpenOffice.org binary.  Specifically, the binary should not
 // be relaunched upon login.
 // 
--- ooqstart-0.8.3.orig/kde/kde.cxx
+++ ooqstart-0.8.3/kde/kde.cxx
@@ -1,5 +1,5 @@
 /*=========================================================================
-| Open Office QuickStarter
+| OpenOffice.org QuickStarter
 |--------------------------------------------------------------------------
 | (c) 2002  Kumaran Santhanam  <kumaran@alumni.stanford.org>
 |
@@ -16,13 +16,13 @@
 // The following features are needed to be equivalent to the GNOME
 // front-end:
 // 
 // 1) Properties dialog with space for location of Open Office
 //    and enable/disable of the applet
 //    
 // 2) Three icons showing applet status:
 //    Stopped, Starting, Running
 //    
 // 3) X11 session management interface to disable Open Office's
 //    relaunch registration with the session manager
 //    
 // 4) Help index page
@@ -16,13 +16,13 @@
 // front-end:
 // 
-// 1) Properties dialog with space for location of Open Office
+// 1) Properties dialog with space for location of OpenOffice.org
 //    and enable/disable of the applet
 //    
@@ -16,13 +16,13 @@
 //    Stopped, Starting, Running
 //    
-// 3) X11 session management interface to disable Open Office's
+// 3) X11 session management interface to disable OpenOffice.org's
 //    relaunch registration with the session manager
 //    
only in patch2:
unchanged: